/***************************************************************************
 * Copyright 2012 by
 *  + Christian-Albrechts-University of Kiel
 *    + Department of Computer Science
 *      + Software Engineering Group 
 *  and others.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 ***************************************************************************/

package kieker.webgui.beans.application;

import java.io.IOException;
import java.util.Properties;

import javax.faces.bean.ApplicationScoped;
import javax.faces.bean.ManagedBean;

import kieker.common.logging.Log;
import kieker.common.logging.LogFactory;

/**
 * The class {@link GlobalPropertiesBean} contains the properties for the application (after reading them from one or more files within the resource-set). It is a
 * singleton
 * class.
 * 
 * @author Nils Christian Ehmke
 * @version 1.0
 */
@ManagedBean
@ApplicationScoped
public final class GlobalPropertiesBean {
	/**
	 * This is the log object which will be used to log errors and exceptions.
	 */
	private static final Log LOG = LogFactory.getLog(GlobalPropertiesBean.class);
	/**
	 * This is the name of the global properties file, which should be contained in the resources of this war-archive.
	 */
	private static final String PROPERTIES_FILE_GLOBAL = "global.properties";
	/**
	 * A property name.
	 */
	private static final String PROPERTY_FACES_CONTEXT_THEME_KEY = "kieker.webgui.theme.facesContextKey";
	/**
	 * A property name.
	 */
	private static final String PROPERTY_THEME_COOKIE_NAME = "kieker.webgui.theme.cookieName";
	/**
	 * A property name.
	 */
	private static final String PROPERTY_DEFAULT_THEME = "kieker.webgui.theme.defaultTheme";
	/**
	 * A property name.
	 */
	private static final String PROPERTY_PROJECT_OVERVIEW_PAGE = "kieker.webgui.page.projectOverview";
	/**
	 * A property name.
	 */
	private static final String PROPERTY_WELCOME_MESSAGE = "kieker.webgui.common.welcomeMessage";
	/**
	 * A property name.
	 */
	private static final String PROPERTY_SHORT_WELCOME_MESSAGE = "kieker.webgui.common.shortWelcomeMessage";
	/**
	 * This field contains the global properties.
	 */
	private final Properties globalProperties = new Properties();

	/**
	 * Default constructor. <b>Do not use this constructor. This bean is JSF managed.</b>
	 */
	public GlobalPropertiesBean() {
		try {
			// Try to load the properties from the properties file(s)
			this.globalProperties.load(Thread.currentThread().getContextClassLoader().getResourceAsStream(GlobalPropertiesBean.PROPERTIES_FILE_GLOBAL));
		} catch (final IOException ex) {
			// If this exception occurs there isn't much we can do. This means the resource isn't available. We can't shutdown the whole application, so instead we
			// log the error.
			GlobalPropertiesBean.LOG.error("An error occured during the loading of the properties", ex);
		}
	}

	/**
	 * Delivers the default theme.
	 * 
	 * @return The stored value of the property.
	 */
	public String getDefaultTheme() {
		return this.globalProperties.getProperty(GlobalPropertiesBean.PROPERTY_DEFAULT_THEME);
	}

	/**
	 * Delivers the name of the theme cookie.
	 * 
	 * @return The stored value of the property.
	 */
	public String getThemeCookieName() {
		return this.globalProperties.getProperty(GlobalPropertiesBean.PROPERTY_THEME_COOKIE_NAME);
	}

	/**
	 * Delivers the key name of the theme within the faces context.
	 * 
	 * @return The stored value of the property.
	 */
	public String getFacesContextThemeKey() {
		return this.globalProperties.getProperty(GlobalPropertiesBean.PROPERTY_FACES_CONTEXT_THEME_KEY);
	}

	/**
	 * Delivers the key name of the theme within the faces context.
	 * 
	 * @return The stored value of the property.
	 */
	public String getProjectOverviewPage() {
		return this.globalProperties.getProperty(GlobalPropertiesBean.PROPERTY_PROJECT_OVERVIEW_PAGE);
	}

	/**
	 * Delivers the welcome message.
	 * 
	 * @return The stored value of the property.
	 */
	public String getWelcomeMessage() {
		return this.globalProperties.getProperty(GlobalPropertiesBean.PROPERTY_WELCOME_MESSAGE);
	}

	/**
	 * Delivers the short welcome message.
	 * 
	 * @return The stored value of the property.
	 */
	public String getShortWelcomeMessage() {
		return this.globalProperties.getProperty(GlobalPropertiesBean.PROPERTY_SHORT_WELCOME_MESSAGE);
	}
}
